# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FREEVIEW_METADATA = Metadata(
    id="ea7d3ba2300d2eb2c6fc1ff4ec8778d1a042e201.boutiques",
    name="freeview",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FreeviewOutputs(typing.NamedTuple):
    """
    Output object returned when calling `freeview(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def freeview(
    args: str | None = None,
    runner: Runner | None = None,
) -> FreeviewOutputs:
    """
    Freeview is a 3D/2D brain visualization tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        args: Arguments for freeview.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FreeviewOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FREEVIEW_METADATA)
    cargs = []
    cargs.append("freeview")
    if args is not None:
        cargs.append(args)
    ret = FreeviewOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FREEVIEW_METADATA",
    "FreeviewOutputs",
    "freeview",
]
