# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_TABLES_RH_METADATA = Metadata(
    id="2f3add04b35d7726ca806ca38014821260043ebc.boutiques",
    name="morph_tables-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphTablesRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_tables_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_tables_rh(
    options: str | None = None,
    runner: Runner | None = None,
) -> MorphTablesRhOutputs:
    """
    A tool from Freesurfer associated with morphological tables for the right
    hemisphere.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        options: Options used by morph_tables-rh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphTablesRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_TABLES_RH_METADATA)
    cargs = []
    if options is not None:
        cargs.extend([
            "-rh",
            "morph_tables" + options
        ])
    ret = MorphTablesRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_TABLES_RH_METADATA",
    "MorphTablesRhOutputs",
    "morph_tables_rh",
]
