# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BROWSE_MINC_HEADER_TCL_METADATA = Metadata(
    id="d9e64b68673469631420a82f8e3342cb78163bcc.boutiques",
    name="browse-minc-header.tcl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BrowseMincHeaderTclOutputs(typing.NamedTuple):
    """
    Output object returned when calling `browse_minc_header_tcl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def browse_minc_header_tcl(
    infile: InputPathType,
    runner: Runner | None = None,
) -> BrowseMincHeaderTclOutputs:
    """
    A tool for browsing MINC file headers, likely part of the FreeSurfer package.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: MINC file for which the header is to be browsed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BrowseMincHeaderTclOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BROWSE_MINC_HEADER_TCL_METADATA)
    cargs = []
    cargs.append("browse-minc-header.tcl")
    cargs.append(execution.input_file(infile))
    ret = BrowseMincHeaderTclOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BROWSE_MINC_HEADER_TCL_METADATA",
    "BrowseMincHeaderTclOutputs",
    "browse_minc_header_tcl",
]
