# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CHECK_MCR_SH_METADATA = Metadata(
    id="791978a63c49f038efea95973ac807e32f4fd537.boutiques",
    name="checkMCR.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class CheckMcrShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `check_mcr_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def check_mcr_sh(
    help_: bool = False,
    runner: Runner | None = None,
) -> CheckMcrShOutputs:
    """
    Script to check for the presence of Matlab Compiler Runtime (MCR) for Matlab
    2019b, used for the hippocampal/amygdala and brainstem modules.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        help_: Display help information about checkMCR.sh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CheckMcrShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CHECK_MCR_SH_METADATA)
    cargs = []
    cargs.append("checkMCR.sh")
    if help_:
        cargs.append("--help")
    ret = CheckMcrShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CHECK_MCR_SH_METADATA",
    "CheckMcrShOutputs",
    "check_mcr_sh",
]
