# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GET_AFNI_MODEL_PRF_6_METADATA = Metadata(
    id="a1644a25504c74d6961d86251212dfc9c7f6fb99.boutiques",
    name="get_afni_model_PRF_6",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GetAfniModelPrf6Outputs(typing.NamedTuple):
    """
    Output object returned when calling `get_afni_model_prf_6(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def get_afni_model_prf_6(
    nt_: float,
    amp: float,
    x: float,
    y: float,
    sigma: float,
    sigrat: float,
    theta: float,
    runner: Runner | None = None,
) -> GetAfniModelPrf6Outputs:
    """
    A command to invoke AFNI's population receptive field (pRF) model.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        nt_: Number of time points of the stimulus dataset.
        amp: Amplitude of the pRF model.
        x: X coordinate of the pRF center.
        y: Y coordinate of the pRF center.
        sigma: Standard deviation of the Gaussian pRF.
        sigrat: Ratio of standard deviations (sigma_x/sigma_y) of the Gaussian\
            pRF.
        theta: Rotation angle theta of the Gaussian pRF.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GetAfniModelPrf6Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GET_AFNI_MODEL_PRF_6_METADATA)
    cargs = []
    cargs.append("get_afni_model_PRF_6")
    cargs.append(str(nt_))
    cargs.append(str(amp))
    cargs.append(str(x))
    cargs.append(str(y))
    cargs.append(str(sigma))
    cargs.append(str(sigrat))
    cargs.append(str(theta))
    ret = GetAfniModelPrf6Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GET_AFNI_MODEL_PRF_6_METADATA",
    "GetAfniModelPrf6Outputs",
    "get_afni_model_prf_6",
]
