# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_NEW_METADATA = Metadata(
    id="c3ea7e0b28d39449428a797435fdabb03c6243ca.boutiques",
    name="inflate_subject_new",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectNewOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_new(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_new(
    subject_dir: str,
    runner: Runner | None = None,
) -> InflateSubjectNewOutputs:
    """
    Tool to inflate subject surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Directory containing the subject data to be inflated.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectNewOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_NEW_METADATA)
    cargs = []
    cargs.append("inflate_subject_new")
    cargs.append(subject_dir)
    ret = InflateSubjectNewOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_NEW_METADATA",
    "InflateSubjectNewOutputs",
    "inflate_subject_new",
]
