# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_STRIP_SUBJECT_INFO_METADATA = Metadata(
    id="7f018807cf37f338df19c441f6450439090921fb.boutiques",
    name="mri_strip_subject_info",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriStripSubjectInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_strip_subject_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_strip_subject_info(
    input_files: list[InputPathType],
    output_directory: str,
    runner: Runner | None = None,
) -> MriStripSubjectInfoOutputs:
    """
    A tool to strip subject information from MRI data files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_files: Input file(s) containing MRI data.
        output_directory: Directory where stripped files will be saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriStripSubjectInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_STRIP_SUBJECT_INFO_METADATA)
    cargs = []
    cargs.append("mri_strip_subject_info")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.append(output_directory)
    ret = MriStripSubjectInfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_STRIP_SUBJECT_INFO_METADATA",
    "MriStripSubjectInfoOutputs",
    "mri_strip_subject_info",
]
