# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_4SWAP_METADATA = Metadata(
    id="b931a726528adf5a726f46c604f9851351673fb9.boutiques",
    name="4swap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V4swapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_4swap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_4swap(
    files: list[InputPathType],
    quiet: bool = False,
    runner: Runner | None = None,
) -> V4swapOutputs:
    """
    Swaps byte quadruples on the listed files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        files: List of files to process.
        quiet: Work quietly; suppress output messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V4swapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_4SWAP_METADATA)
    cargs = []
    cargs.append("4swap")
    cargs.extend([execution.input_file(f) for f in files])
    if quiet:
        cargs.append("-q")
    ret = V4swapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V4swapOutputs",
    "V_4SWAP_METADATA",
    "v_4swap",
]
