# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__HELP_AFNI_METADATA = Metadata(
    id="87ebd1e4083856099825a6ef50fde5abb2dad615.boutiques",
    name="@help.AFNI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VHelpAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__help_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__help_afni(
    runner: Runner | None = None,
) -> VHelpAfniOutputs:
    """
    A script to retrieve and search AFNI's help page for all programs.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VHelpAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__HELP_AFNI_METADATA)
    cargs = []
    cargs.append("@help.AFNI")
    cargs.append("[OPTIONS]")
    ret = VHelpAfniOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VHelpAfniOutputs",
    "V__HELP_AFNI_METADATA",
    "v__help_afni",
]
