# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MPR2MNI305_METADATA = Metadata(
    id="43f9475eba43e43bb6641a614ad0e97898040bbb.boutiques",
    name="mpr2mni305",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Mpr2mni305Outputs(typing.NamedTuple):
    """
    Output object returned when calling `mpr2mni305(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mpr2mni305(
    mpr_anat: str,
    runner: Runner | None = None,
) -> Mpr2mni305Outputs:
    """
    Tool for transforming MPRAGE dataset to MNI305 coordinate space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mpr_anat: MPRAGE anatomical input file (e.g., 131).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Mpr2mni305Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MPR2MNI305_METADATA)
    cargs = []
    cargs.append("mpr2mni305")
    cargs.append(mpr_anat)
    ret = Mpr2mni305Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MPR2MNI305_METADATA",
    "Mpr2mni305Outputs",
    "mpr2mni305",
]
