# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_X_METADATA = Metadata(
    id="92fc476ae5e966d3c5014f57b61d18334a4b32e8.boutiques",
    name="tbss_x",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class TbssXOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_x(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tbss_x(
    scalar_dirs: list[str],
    vector_dirs: list[str],
    runner: Runner | None = None,
) -> TbssXOutputs:
    """
    TBSS cross-subject script for processing scalar and vector directories.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        scalar_dirs: List of scalar directories (e.g., F1, F2).
        vector_dirs: List of vector directories (e.g., D1, D2).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TbssXOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_X_METADATA)
    cargs = []
    cargs.append("tbss_x")
    cargs.extend(scalar_dirs)
    cargs.extend(vector_dirs)
    ret = TbssXOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_X_METADATA",
    "TbssXOutputs",
    "tbss_x",
]
