# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IREPIFITVOL_GLNX64_METADATA = Metadata(
    id="e1b3c71003d88eeb91c6bc522cbeb9c8dec5641d.boutiques",
    name="irepifitvol.glnx64",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IrepifitvolGlnx64Outputs(typing.NamedTuple):
    """
    Output object returned when calling `irepifitvol_glnx64(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """The fitted volume output from the irepifitvol process."""


def irepifitvol_glnx64(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> IrepifitvolGlnx64Outputs:
    """
    This tool is a part of the FreeSurfer toolkit, designed for certain volume
    fitting tasks.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: The input volume file to be processed.
        output_file: The path to save the output volume file after fitting.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IrepifitvolGlnx64Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IREPIFITVOL_GLNX64_METADATA)
    cargs = []
    cargs.append("irepifitvol")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = IrepifitvolGlnx64Outputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IREPIFITVOL_GLNX64_METADATA",
    "IrepifitvolGlnx64Outputs",
    "irepifitvol_glnx64",
]
