# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__TIME_DIFF_METADATA = Metadata(
    id="7889ba0aeecc01a9a55b923b84e149e7cec9417e.boutiques",
    name="@TimeDiff",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VTimeDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__time_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__time_diff(
    file1: InputPathType,
    file2: InputPathType,
    runner: Runner | None = None,
) -> VTimeDiffOutputs:
    """
    A tool to compare the modification times of two files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        file1: First file to compare (e.g., file1.txt).
        file2: Second file to compare (e.g., file2.txt).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VTimeDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__TIME_DIFF_METADATA)
    cargs = []
    cargs.append("@TimeDiff")
    cargs.append(execution.input_file(file1))
    cargs.append(execution.input_file(file2))
    ret = VTimeDiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VTimeDiffOutputs",
    "V__TIME_DIFF_METADATA",
    "v__time_diff",
]
