# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AFNI_RUN_ME_METADATA = Metadata(
    id="aeac26149fa34d0c42e1c07c261b19ac0706d90b.boutiques",
    name="@afni.run.me",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAfniRunMeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__afni_run_me(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__afni_run_me(
    go: bool = False,
    curl: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> VAfniRunMeOutputs:
    """
    A tool to execute a specific command.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        go: Execute the work.
        curl: Default to curl instead of wget.
        help_: Show help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAfniRunMeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AFNI_RUN_ME_METADATA)
    cargs = []
    cargs.append("@afni.run.me")
    if go:
        cargs.append("-go")
    if curl:
        cargs.append("-curl")
    if help_:
        cargs.append("-help")
    ret = VAfniRunMeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAfniRunMeOutputs",
    "V__AFNI_RUN_ME_METADATA",
    "v__afni_run_me",
]
