# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_CALC_MONT_DIMS_PY_METADATA = Metadata(
    id="4d9e1251726a46e6f7e2c846f8a4c9e80c3f25b6.boutiques",
    name="adjunct_calc_mont_dims.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctCalcMontDimsPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_calc_mont_dims_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def adjunct_calc_mont_dims_py(
    help_: bool = False,
    runner: Runner | None = None,
) -> AdjunctCalcMontDimsPyOutputs:
    """
    A helper function for the fat_proc* scripts.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        help_: Display help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctCalcMontDimsPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_CALC_MONT_DIMS_PY_METADATA)
    cargs = []
    cargs.append("adjunct_calc_mont_dims.py")
    if help_:
        cargs.append("-help")
    ret = AdjunctCalcMontDimsPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_CALC_MONT_DIMS_PY_METADATA",
    "AdjunctCalcMontDimsPyOutputs",
    "adjunct_calc_mont_dims_py",
]
