# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GET_AFNI_MODEL_PRF_6_BAD_METADATA = Metadata(
    id="f7614b8ced72773ab9bfd46ff569ff9a092b84e3.boutiques",
    name="get_afni_model_PRF_6_BAD",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GetAfniModelPrf6BadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `get_afni_model_prf_6_bad(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def get_afni_model_prf_6_bad(
    amplitude: float,
    x_coord: float,
    y_coord: float,
    sigma: float,
    sigrat: float,
    theta: float,
    runner: Runner | None = None,
) -> GetAfniModelPrf6BadOutputs:
    """
    Command line tool for obtaining AFNI pRF model.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        amplitude: Amplitude parameter A.
        x_coord: X coordinate parameter x.
        y_coord: Y coordinate parameter y.
        sigma: Sigma parameter sigma.
        sigrat: Sigma ratio parameter sigrat.
        theta: Theta parameter theta (in radians).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GetAfniModelPrf6BadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GET_AFNI_MODEL_PRF_6_BAD_METADATA)
    cargs = []
    cargs.append("get_afni_model_PRF_6_BAD")
    cargs.append(str(amplitude))
    cargs.append(str(x_coord))
    cargs.append(str(y_coord))
    cargs.append(str(sigma))
    cargs.append(str(sigrat))
    cargs.append(str(theta))
    ret = GetAfniModelPrf6BadOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GET_AFNI_MODEL_PRF_6_BAD_METADATA",
    "GetAfniModelPrf6BadOutputs",
    "get_afni_model_prf_6_bad",
]
