# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GDFGLM_METADATA = Metadata(
    id="6bfd0a6b2b32f6fa09eb9767dc1f8e35ce2df1d6.boutiques",
    name="mri_gdfglm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGdfglmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gdfglm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outputs: OutputPathType
    """Output information is not available because the command has been
    removed."""


def mri_gdfglm(
    runner: Runner | None = None,
) -> MriGdfglmOutputs:
    """
    The mri_gdfglm command has been removed from the current version of FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGdfglmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GDFGLM_METADATA)
    cargs = []
    cargs.append("mri_gdfglm")
    ret = MriGdfglmOutputs(
        root=execution.output_file("."),
        outputs=execution.output_file("[OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GDFGLM_METADATA",
    "MriGdfglmOutputs",
    "mri_gdfglm",
]
