# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AFNITO_NIML_METADATA = Metadata(
    id="98f63f2e946d67b9373a37700e5abbc719dca8ea.boutiques",
    name="3dAFNItoNIML",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAfnitoNimlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_afnito_niml(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_afnito_niml(
    dset: InputPathType,
    runner: Runner | None = None,
) -> V3dAfnitoNimlOutputs:
    """
    Dumps AFNI dataset header information to stdout in NIML format. Mostly for
    debugging and testing purposes!.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dset: AFNI dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAfnitoNimlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AFNITO_NIML_METADATA)
    cargs = []
    cargs.append("3dAFNItoNIML")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dset))
    ret = V3dAfnitoNimlOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAfnitoNimlOutputs",
    "V_3D_AFNITO_NIML_METADATA",
    "v_3d_afnito_niml",
]
