# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPHERE_SUBJECT_RH_METADATA = Metadata(
    id="844b29d70c1496f2da433daa0b47df80e286dc3b.boutiques",
    name="sphere_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SphereSubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sphere_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def sphere_subject_rh(
    license_file: InputPathType,
    runner: Runner | None = None,
) -> SphereSubjectRhOutputs:
    """
    Sphere Subject RH tool for FreeSurfer, requires valid license.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        license_file: Path to FreeSurfer license file, can be specified with\
            the FS_LICENSE environmental variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SphereSubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPHERE_SUBJECT_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "sphere_subject" + execution.input_file(license_file)
    ])
    ret = SphereSubjectRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPHERE_SUBJECT_RH_METADATA",
    "SphereSubjectRhOutputs",
    "sphere_subject_rh",
]
