# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__CLUST_EXP_CAT_LAB_METADATA = Metadata(
    id="e3acc2b13b06a35c413b7c5aede3d8651316dbe3.boutiques",
    name="@ClustExp_CatLab",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VClustExpCatLabOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__clust_exp_cat_lab(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output data set concatenating labeled subbriks"""


def v__clust_exp_cat_lab(
    prefix: str,
    input_file: InputPathType,
    help_: bool = False,
    runner: Runner | None = None,
) -> VClustExpCatLabOutputs:
    """
    Helper script to concatenate and label a group of data sets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Output file name.
        input_file: Name of file containing the labels and data sets table\
            (e.g. subjects.csv).
        help_: Show help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VClustExpCatLabOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__CLUST_EXP_CAT_LAB_METADATA)
    cargs = []
    cargs.append("@ClustExp_CatLab")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    if help_:
        cargs.append("-help")
    ret = VClustExpCatLabOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VClustExpCatLabOutputs",
    "V__CLUST_EXP_CAT_LAB_METADATA",
    "v__clust_exp_cat_lab",
]
