# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_SUBJECT_RH_METADATA = Metadata(
    id="f2d5e549617839220f590599e3a6e8f1eae8c024.boutiques",
    name="morph_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphSubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_subject_rh(
    subject_id: str,
    runner: Runner | None = None,
) -> MorphSubjectRhOutputs:
    """
    A tool for morphing the right hemisphere of subject data in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject ID to morph the right hemisphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphSubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_SUBJECT_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "morph_subject" + subject_id
    ])
    ret = MorphSubjectRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_SUBJECT_RH_METADATA",
    "MorphSubjectRhOutputs",
    "morph_subject_rh",
]
