# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_RGB_RH_METADATA = Metadata(
    id="d9ff451dc5d9779a26edbf9b5422cc9aac7df58e.boutiques",
    name="morph_rgb-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphRgbRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_rgb_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_rgb_rh(
    subject_id: str,
    runner: Runner | None = None,
) -> MorphRgbRhOutputs:
    """
    Morphs RGB values onto a FreeSurfer right hemisphere surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject ID for which the RGB morphing should be performed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphRgbRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_RGB_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "morph_rgb" + subject_id
    ])
    ret = MorphRgbRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_RGB_RH_METADATA",
    "MorphRgbRhOutputs",
    "morph_rgb_rh",
]
