# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_NEW_RH_METADATA = Metadata(
    id="6ededf15eee0d58308af964a359eb602b1b300a0.boutiques",
    name="inflate_subject_new-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectNewRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_new_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_new_rh(
    args: str | None = None,
    runner: Runner | None = None,
) -> InflateSubjectNewRhOutputs:
    """
    This is a placeholder descriptor for the 'inflate_subject_new-rh' command. The
    tool appears to be part of FreeSurfer but the specific inputs, outputs or
    options couldn't be extracted from the help text.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        args: Additional command-line arguments for inflate_subject_new-rh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectNewRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_NEW_RH_METADATA)
    cargs = []
    if args is not None:
        cargs.extend([
            "-rh",
            "inflate_subject_new" + args
        ])
    ret = InflateSubjectNewRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_NEW_RH_METADATA",
    "InflateSubjectNewRhOutputs",
    "inflate_subject_new_rh",
]
