# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_EMPTY_METADATA = Metadata(
    id="458e0d6419fbf58fb595b4f42ae970422fb2886a.boutiques",
    name="3dEmpty",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dEmptyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_empty(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """Output empty dataset header file"""


def v_3d_empty(
    prefix: str | None = None,
    geometry: str | None = None,
    nxyz: list[float] | None = None,
    nt_: float | None = None,
    runner: Runner | None = None,
) -> V3dEmptyOutputs:
    """
    Tool to create an 'empty' dataset .HEAD file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Prefix name for output file (default = 'Empty').
        geometry: Set the 3D geometry of the grid using a string of the form\
            'MATRIX(a11,a12,a13,a14,a21,a22,a23,a24,a31,a32,a33,a34):nx,ny,nz'.
        nxyz: Set number of voxels to 'x', 'y', and 'z' along the 3 axes\
            [defaults=64].
        nt_: Number of time points [default=1].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dEmptyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_EMPTY_METADATA)
    cargs = []
    cargs.append("3dEmpty")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if geometry is not None:
        cargs.extend([
            "-geometry",
            geometry
        ])
    if nxyz is not None:
        cargs.extend([
            "-nxyz",
            *map(str, nxyz)
        ])
    if nt_ is not None:
        cargs.extend([
            "-nt",
            str(nt_)
        ])
    ret = V3dEmptyOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(prefix + ".HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dEmptyOutputs",
    "V_3D_EMPTY_METADATA",
    "v_3d_empty",
]
