# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REINFLATE_SUBJECT_METADATA = Metadata(
    id="1e08a83747d403bdb6fd509a84d2ca27a452f873.boutiques",
    name="reinflate_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ReinflateSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reinflate_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def reinflate_subject(
    args: str | None = None,
    runner: Runner | None = None,
) -> ReinflateSubjectOutputs:
    """
    Tool for reinflating brain surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        args: Arguments for reinflate_subject.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReinflateSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REINFLATE_SUBJECT_METADATA)
    cargs = []
    cargs.append("reinflate_subject")
    if args is not None:
        cargs.append(args)
    ret = ReinflateSubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REINFLATE_SUBJECT_METADATA",
    "ReinflateSubjectOutputs",
    "reinflate_subject",
]
