# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CHECK_SUBJECT_METADATA = Metadata(
    id="a469eabd7979354cb8f4da4909edfba7eca4707c.boutiques",
    name="check_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class CheckSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `check_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def check_subject(
    subject_dir: str,
    runner: Runner | None = None,
) -> CheckSubjectOutputs:
    """
    Checks a subject directory for the existence of a surf directory.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Path to the subject directory to check.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CheckSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CHECK_SUBJECT_METADATA)
    cargs = []
    cargs.append("check_subject")
    cargs.append(subject_dir)
    ret = CheckSubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CHECK_SUBJECT_METADATA",
    "CheckSubjectOutputs",
    "check_subject",
]
