# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BUILD_DESIKAN_KILLIANY_GCS_CSH_METADATA = Metadata(
    id="533d45cdbfae4bc58aadf050a7461db1dc6a6914.boutiques",
    name="build_desikan_killiany_gcs.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BuildDesikanKillianyGcsCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `build_desikan_killiany_gcs_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def build_desikan_killiany_gcs_csh(
    hemi: str,
    runner: Runner | None = None,
) -> BuildDesikanKillianyGcsCshOutputs:
    """
    Tool to build Desikan-Killiany cortical parcellation in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: Hemisphere designation for the operation. Should be 'rh' for\
            right hemisphere or 'lh' for left hemisphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BuildDesikanKillianyGcsCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BUILD_DESIKAN_KILLIANY_GCS_CSH_METADATA)
    cargs = []
    cargs.append("build_desikan_killiany_gcs.csh")
    cargs.append(hemi)
    ret = BuildDesikanKillianyGcsCshOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BUILD_DESIKAN_KILLIANY_GCS_CSH_METADATA",
    "BuildDesikanKillianyGcsCshOutputs",
    "build_desikan_killiany_gcs_csh",
]
