# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TAL_QC_AZS_METADATA = Metadata(
    id="886563f0c6afbd7ecc04616fab1fcccc741bff0c.boutiques",
    name="tal_QC_AZS",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalQcAzsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tal_qc_azs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tal_qc_azs(
    logfile: InputPathType,
    runner: Runner | None = None,
) -> TalQcAzsOutputs:
    """
    A tool that processes a logfile.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        logfile: Input logfile for processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalQcAzsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TAL_QC_AZS_METADATA)
    cargs = []
    cargs.append("tal_QC_AZS")
    cargs.append(execution.input_file(logfile))
    ret = TalQcAzsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TAL_QC_AZS_METADATA",
    "TalQcAzsOutputs",
    "tal_qc_azs",
]
