# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSFIRST_FSL_METADATA = Metadata(
    id="fe4368d67f0bf44514ba8d3556dd0dd0df276d60.boutiques",
    name="fsfirst.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsfirstFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsfirst_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsfirst_fsl(
    runner: Runner | None = None,
) -> FsfirstFslOutputs:
    """
    The tool intended for FSL's FIRST module, responsible for model-based
    segmentation and registration of subcortical structures.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsfirstFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSFIRST_FSL_METADATA)
    cargs = []
    cargs.append("fsfirst.fsl")
    ret = FsfirstFslOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSFIRST_FSL_METADATA",
    "FsfirstFslOutputs",
    "fsfirst_fsl",
]
