# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_LH_METADATA = Metadata(
    id="13f58b307e30c9d1d7c23e3d8eda03727c68266d.boutiques",
    name="inflate_subject-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_lh(
    input_folder: str,
    hostname_flag: bool = False,
    runner: Runner | None = None,
) -> InflateSubjectLhOutputs:
    """
    A tool to process and inflate left hemisphere subject data in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_folder: Input folder containing subject data.
        hostname_flag: Flag to check hostname.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "inflate_subject" + input_folder
    ])
    if hostname_flag:
        cargs.append("hostname")
    ret = InflateSubjectLhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_LH_METADATA",
    "InflateSubjectLhOutputs",
    "inflate_subject_lh",
]
