# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_TUTORIAL_DATA_METADATA = Metadata(
    id="80182cd74220da19e2c55dc09c1599b0b78de72e.boutiques",
    name="fs_tutorial_data",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsTutorialDataOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_tutorial_data(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tutorial_data_dir: OutputPathType
    """Directory where tutorial data will be downloaded and installed."""


def fs_tutorial_data(
    rsync_options: list[str] | None = None,
    runner: Runner | None = None,
) -> FsTutorialDataOutputs:
    """
    Tool to download and install FreeSurfer tutorial data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        rsync_options: Additional rsync options for downloading tutorial data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsTutorialDataOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_TUTORIAL_DATA_METADATA)
    cargs = []
    cargs.append("fs_tutorial_data")
    if rsync_options is not None:
        cargs.extend(rsync_options)
    ret = FsTutorialDataOutputs(
        root=execution.output_file("."),
        tutorial_data_dir=execution.output_file("/usr/local/freesurfer/subjects/tutorial_data"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_TUTORIAL_DATA_METADATA",
    "FsTutorialDataOutputs",
    "fs_tutorial_data",
]
