# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REMOVE_TALAIRACH_METADATA = Metadata(
    id="4b227d57c6cc0632758ead5783a3cd254592158b.boutiques",
    name="remove_talairach",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RemoveTalairachOutputs(typing.NamedTuple):
    """
    Output object returned when calling `remove_talairach(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Output volume with Talairach transformation removed"""


def remove_talairach(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> RemoveTalairachOutputs:
    """
    A tool for removing the Talairach transformation from a volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume with Talairach transformation (e.g.,\
            volume.nii).
        output_file: Output volume after removing Talairach transformation\
            (e.g., volume_notal.nii).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RemoveTalairachOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REMOVE_TALAIRACH_METADATA)
    cargs = []
    cargs.append("remove_talairach")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = RemoveTalairachOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REMOVE_TALAIRACH_METADATA",
    "RemoveTalairachOutputs",
    "remove_talairach",
]
