# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_TALAIRACH_METADATA = Metadata(
    id="2a27ec50232d56f8e8e079035c459f747d644292.boutiques",
    name="mris_talairach",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisTalairachOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_talairach(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_talairach(
    input_image: InputPathType,
    runner: Runner | None = None,
) -> MrisTalairachOutputs:
    """
    Transforms an MRI surface into Talairach space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: Input image file to be transformed into Talairach space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTalairachOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TALAIRACH_METADATA)
    cargs = []
    cargs.append("mris_talairach")
    cargs.append(execution.input_file(input_image))
    ret = MrisTalairachOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_TALAIRACH_METADATA",
    "MrisTalairachOutputs",
    "mris_talairach",
]
