# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_TRANSFORM_INFO_METADATA = Metadata(
    id="db110d69e8361c7a0293d1d70937a09c146e535a.boutiques",
    name="antsTransformInfo",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsTransformInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_transform_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_info: OutputPathType
    """Information of the provided transform file."""


def ants_transform_info(
    transform_file: InputPathType,
    runner: Runner | None = None,
) -> AntsTransformInfoOutputs:
    """
    Provide information about an ITK transform file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        transform_file: The transform file to read. Supported formats include\
            HDF5, MINC, Matlab, and Txt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsTransformInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_TRANSFORM_INFO_METADATA)
    cargs = []
    cargs.append("antsTransformInfo")
    cargs.extend([
        "--file",
        execution.input_file(transform_file)
    ])
    ret = AntsTransformInfoOutputs(
        root=execution.output_file("."),
        output_info=execution.output_file("transform_info.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_TRANSFORM_INFO_METADATA",
    "AntsTransformInfoOutputs",
    "ants_transform_info",
]
