# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GCATRAINSKULL_METADATA = Metadata(
    id="89af41167df36313b39cb032d8e1c2c288ba043b.boutiques",
    name="gcatrainskull",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GcatrainskullOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gcatrainskull(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gcatrainskull(
    gcatrain_dir: str,
    runner: Runner | None = None,
) -> GcatrainskullOutputs:
    """
    GCA train skull stripping tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        gcatrain_dir: Directory containing GCA training data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GcatrainskullOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GCATRAINSKULL_METADATA)
    cargs = []
    cargs.append("gcatrainskull")
    cargs.extend([
        "--g",
        gcatrain_dir
    ])
    ret = GcatrainskullOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GCATRAINSKULL_METADATA",
    "GcatrainskullOutputs",
    "gcatrainskull",
]
