# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_RGB_LH_METADATA = Metadata(
    id="8a27176b135c7e00506bbb223dc33d4f8b5c331f.boutiques",
    name="morph_rgb-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphRgbLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_rgb_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_rgb_lh(
    subject_id: str,
    runner: Runner | None = None,
) -> MorphRgbLhOutputs:
    """
    Tool for working with and generating RGB images of morphometric data for the
    left hemisphere in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: The subject ID to process. This refers to the sub-directory\
            within $SUBJECTS_DIR containing the FreeSurfer processed data for the\
            subject.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphRgbLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_RGB_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "morph_rgb" + subject_id
    ])
    ret = MorphRgbLhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_RGB_LH_METADATA",
    "MorphRgbLhOutputs",
    "morph_rgb_lh",
]
