# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GCAB_TRAIN_METADATA = Metadata(
    id="5b3336956c10bad5fe64ad5c8c726b6429d9bf74.boutiques",
    name="mri_gcab_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGcabTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gcab_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_gcab_train(
    runner: Runner | None = None,
) -> MriGcabTrainOutputs:
    """
    Previously used command in FreeSurfer for training with Gaussian Classifier
    Atlas-based (GCAB) modeling; has been removed in the current version.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGcabTrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GCAB_TRAIN_METADATA)
    cargs = []
    cargs.append("mri_gcab_train")
    ret = MriGcabTrainOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GCAB_TRAIN_METADATA",
    "MriGcabTrainOutputs",
    "mri_gcab_train",
]
