# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_TABLES_LH_METADATA = Metadata(
    id="e50487cf18790588cbef4e2983a79d88589f3cc3.boutiques",
    name="morph_tables-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphTablesLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_tables_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output results from morphological analysis (example, adjust as needed)"""


def morph_tables_lh(
    input_file: InputPathType,
    some_flag: bool = False,
    runner: Runner | None = None,
) -> MorphTablesLhOutputs:
    """
    Morphological analysis tool for left hemisphere in Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file for morphological analysis.
        some_flag: Example flag (replace with actual options from tool if\
            known).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphTablesLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_TABLES_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "morph_tables" + execution.input_file(input_file)
    ])
    if some_flag:
        cargs.append("--some-flag")
    ret = MorphTablesLhOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(input_file).name + "_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_TABLES_LH_METADATA",
    "MorphTablesLhOutputs",
    "morph_tables_lh",
]
