# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_ONLY_SUBJECT_METADATA = Metadata(
    id="bff2c0f8f21164dcde88d76e1c6a7e662e454b4a.boutiques",
    name="morph_only_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphOnlySubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_only_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_only_subject(
    placeholder_input: str | None = None,
    runner: Runner | None = None,
) -> MorphOnlySubjectOutputs:
    """
    A placeholder descriptor for morph_only_subject tool as help content is
    unavailable.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        placeholder_input: Placeholder input argument for morph_only_subject\
            tool.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphOnlySubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_ONLY_SUBJECT_METADATA)
    cargs = []
    cargs.append("morph_only_subject")
    if placeholder_input is not None:
        cargs.append(placeholder_input)
    ret = MorphOnlySubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_ONLY_SUBJECT_METADATA",
    "MorphOnlySubjectOutputs",
    "morph_only_subject",
]
