# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_5_0_2_XYZTRANS_SCH_METADATA = Metadata(
    id="97a334fb37fbd008c00e7f8cd6895c30829fe6b3.boutiques",
    name="fsl.5.0.2.xyztrans.sch",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Fsl502XyztransSchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_5_0_2_xyztrans_sch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_5_0_2_xyztrans_sch(
    term_option: str | None = None,
    version_flag: bool = False,
    no_scrollback_flag: bool = False,
    runner: Runner | None = None,
) -> Fsl502XyztransSchOutputs:
    """
    A script with unclear functionality, potentially related to terminal operations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        term_option: Use this instead of the $TERM environment variable.
        version_flag: Print the curses library version used.
        no_scrollback_flag: Do not try to clear the scrollback buffer.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fsl502XyztransSchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_5_0_2_XYZTRANS_SCH_METADATA)
    cargs = []
    cargs.append("fsl.5.0.2.xyztrans.sch")
    if term_option is not None:
        cargs.extend([
            "-T",
            term_option
        ])
    if version_flag:
        cargs.append("-V")
    if no_scrollback_flag:
        cargs.append("-x")
    ret = Fsl502XyztransSchOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_5_0_2_XYZTRANS_SCH_METADATA",
    "Fsl502XyztransSchOutputs",
    "fsl_5_0_2_xyztrans_sch",
]
