# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIDUCIALS_CORRECTION_METADATA = Metadata(
    id="4c8ff34a05a460d57cf9bd6ab63606fa5145834f.boutiques",
    name="fiducials_correction",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FiducialsCorrectionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fiducials_correction(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file with corrected fiducial markers."""


def fiducials_correction(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> FiducialsCorrectionOutputs:
    """
    A tool for correcting fiducial markers in imaging data. Note: This command has
    dependency issues with the Qt platform plugin 'xcb'. Ensure dependencies are
    properly configured.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file containing imaging data with fiducial markers to\
            correct.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FiducialsCorrectionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIDUCIALS_CORRECTION_METADATA)
    cargs = []
    cargs.append("fiducials_correction")
    cargs.append(execution.input_file(input_file))
    cargs.append("[OUTPUT_FILE]")
    ret = FiducialsCorrectionOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIDUCIALS_CORRECTION_METADATA",
    "FiducialsCorrectionOutputs",
    "fiducials_correction",
]
