# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_DIMS_METADATA = Metadata(
    id="eeaee23c17f988ab29947856353b846c3907f154.boutiques",
    name="@GetAfniDims",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniDimsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_dims(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dims_output: OutputPathType
    """Text file containing the dimensions of the input dataset"""


def v__get_afni_dims(
    input_dset: InputPathType,
    runner: Runner | None = None,
) -> VGetAfniDimsOutputs:
    """
    A utility tool to return dimensions of AFNI dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dset: Input AFNI dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniDimsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_DIMS_METADATA)
    cargs = []
    cargs.append("@GetAfniDims")
    cargs.append(execution.input_file(input_dset))
    ret = VGetAfniDimsOutputs(
        root=execution.output_file("."),
        dims_output=execution.output_file("dims_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniDimsOutputs",
    "V__GET_AFNI_DIMS_METADATA",
    "v__get_afni_dims",
]
