# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS2RGB_METADATA = Metadata(
    id="818f21a5949f0f382881eefc95f28854696728c3.boutiques",
    name="mris2rgb",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Mris2rgbOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris2rgb(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris2rgb(
    library_path: str,
    runner: Runner | None = None,
) -> Mris2rgbOutputs:
    """
    A tool from FreeSurfer for converting MRI surface files to RGB images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        library_path: Path to the directory containing the libGLU.so.1 library\
            required by mris2rgb.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Mris2rgbOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS2RGB_METADATA)
    cargs = []
    cargs.append("mris2rgb")
    cargs.extend([
        "export LD_LIBRARY_PATH=",
        library_path
    ])
    ret = Mris2rgbOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS2RGB_METADATA",
    "Mris2rgbOutputs",
    "mris2rgb",
]
