# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HIAM_MAKE_SURFACES_METADATA = Metadata(
    id="eedce2967ed9d851c796ec7ce683d74d056d3684.boutiques",
    name="hiam_make_surfaces",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class HiamMakeSurfacesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `hiam_make_surfaces(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def hiam_make_surfaces(
    subject_name: str,
    structure: typing.Literal["RA", "LA", "RH", "LH"],
    runner: Runner | None = None,
) -> HiamMakeSurfacesOutputs:
    """
    Surface creation tool for specified brain structures.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name for which surfaces are to be created.
        structure: Structure for which surfaces will be created. Valid values\
            are RA, LA, RH, and LH.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `HiamMakeSurfacesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HIAM_MAKE_SURFACES_METADATA)
    cargs = []
    cargs.append("hiam_make_surfaces")
    cargs.append("[OPTIONS]")
    cargs.append(subject_name)
    cargs.append(structure)
    ret = HiamMakeSurfacesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HIAM_MAKE_SURFACES_METADATA",
    "HiamMakeSurfacesOutputs",
    "hiam_make_surfaces",
]
