# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_INSTALL_MCR_METADATA = Metadata(
    id="3368d00255c0d7e5b75947a021056a82a28657ea.boutiques",
    name="fs_install_mcr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsInstallMcrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_install_mcr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_install_mcr(
    mcr_version: str,
    runner: Runner | None = None,
) -> FsInstallMcrOutputs:
    """
    MCR installation tool for FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mcr_version: Specify the MATLAB Compiler Runtime (MCR) version to\
            install.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsInstallMcrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_INSTALL_MCR_METADATA)
    cargs = []
    cargs.append("fs_install_mcr")
    cargs.append(mcr_version)
    ret = FsInstallMcrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_INSTALL_MCR_METADATA",
    "FsInstallMcrOutputs",
    "fs_install_mcr",
]
