# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLIRT_NEWDEFAULT_20080811_SCH_METADATA = Metadata(
    id="0d9d4a730463f50ed6f5eaf534671e8d5ad1f460.boutiques",
    name="flirt.newdefault.20080811.sch",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FlirtNewdefault20080811SchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `flirt_newdefault_20080811_sch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def flirt_newdefault_20080811_sch(
    term_option: str | None = None,
    curses_flag: bool = False,
    scrollback_flag: bool = False,
    runner: Runner | None = None,
) -> FlirtNewdefault20080811SchOutputs:
    """
    FLIRT (FMRIB's Linear Image Registration Tool) new default configuration script.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        term_option: Use this terminal type instead of $TERM.
        curses_flag: Print curses-version.
        scrollback_flag: Do not try to clear scrollback.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FlirtNewdefault20080811SchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLIRT_NEWDEFAULT_20080811_SCH_METADATA)
    cargs = []
    cargs.append("flirt.newdefault.20080811.sch")
    if term_option is not None:
        cargs.extend([
            "-T",
            term_option
        ])
    if curses_flag:
        cargs.append("-V")
    if scrollback_flag:
        cargs.append("-x")
    ret = FlirtNewdefault20080811SchOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLIRT_NEWDEFAULT_20080811_SCH_METADATA",
    "FlirtNewdefault20080811SchOutputs",
    "flirt_newdefault_20080811_sch",
]
