# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_AC_SH_METADATA = Metadata(
    id="a5e9ef0f18ba9932988056847d608cbe806d5bed.boutiques",
    name="dmri_ac.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriAcShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_ac_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_ac_sh(
    additional_args: str | None = None,
    runner: Runner | None = None,
) -> DmriAcShOutputs:
    """
    A script related to diffusion MRI processing in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        additional_args: Additional arguments for dmri_ac.sh script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriAcShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_AC_SH_METADATA)
    cargs = []
    cargs.append("dmri_ac.sh")
    if additional_args is not None:
        cargs.append(additional_args)
    ret = DmriAcShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_AC_SH_METADATA",
    "DmriAcShOutputs",
    "dmri_ac_sh",
]
