# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_MULTIVARIATE_TEMPLATE_CONSTRUCTION2_SH_METADATA = Metadata(
    id="b866ae2f76511eca887345fe0515e30b2318f31e.boutiques",
    name="antsMultivariateTemplateConstruction2.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsMultivariateTemplateConstruction2ShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_multivariate_template_construction2_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    template: OutputPathType
    """The output multivariate template."""


def ants_multivariate_template_construction2_sh(
    input_: str,
    runner: Runner | None = None,
) -> AntsMultivariateTemplateConstruction2ShOutputs:
    """
    The antsMultivariateTemplateConstruction2.sh script is part of the Advanced
    Normalization Tools (ANTs) suite. It is used for constructing multivariate
    templates.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_: Options for setting up and running the multivariate template\
            construction process.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsMultivariateTemplateConstruction2ShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_MULTIVARIATE_TEMPLATE_CONSTRUCTION2_SH_METADATA)
    cargs = []
    cargs.append("antsMultivariateTemplateConstruction2.sh")
    cargs.append(input_)
    ret = AntsMultivariateTemplateConstruction2ShOutputs(
        root=execution.output_file("."),
        template=execution.output_file("<output-prefix>Template.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_MULTIVARIATE_TEMPLATE_CONSTRUCTION2_SH_METADATA",
    "AntsMultivariateTemplateConstruction2ShOutputs",
    "ants_multivariate_template_construction2_sh",
]
