"""
MRTrix3Tissue

MRtrix3Tissue is a fork of the MRtrix3 project. It aims to add capabilities for
3-Tissue CSD modelling and analysis to a complete version of the MRtrix3
software.

URL: https://3tissue.github.io/
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .ss3t_csd_beta1 import *
