# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_HEAD_METADATA = Metadata(
    id="fb167e02a7257ba8b9a2343709e24ec6a1664305.boutiques",
    name="mri_head",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriHeadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_head(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_head(
    identify: bool = False,
    read: bool = False,
    filename: str | None = None,
    question_mark_help: bool = False,
    runner: Runner | None = None,
) -> MriHeadOutputs:
    """
    No description.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        identify: Identify the MRI file.
        read: Read the MRI file.
        filename: Filename for identification or reading.
        question_mark_help: Display help or usage information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriHeadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_HEAD_METADATA)
    cargs = []
    cargs.append("mri_head")
    if identify:
        cargs.append("-identify")
    if read:
        cargs.append("-read")
    if filename is not None:
        cargs.append(filename)
    if question_mark_help:
        cargs.append("-?")
    ret = MriHeadOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_HEAD_METADATA",
    "MriHeadOutputs",
    "mri_head",
]
