# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_ADD_TEMPLATE_METADATA = Metadata(
    id="cad5f1397d4979ef787014fa2412a1f0a10cfe8b.boutiques",
    name="mris_add_template",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisAddTemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_add_template(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    placeholder_output: OutputPathType
    """No outputs available as the tool has been removed."""


def mris_add_template(
    runner: Runner | None = None,
) -> MrisAddTemplateOutputs:
    """
    This tool has been removed from the current version of FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisAddTemplateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_ADD_TEMPLATE_METADATA)
    cargs = []
    cargs.append("mris_add_template")
    ret = MrisAddTemplateOutputs(
        root=execution.output_file("."),
        placeholder_output=execution.output_file("[PLACEHOLDER_OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_ADD_TEMPLATE_METADATA",
    "MrisAddTemplateOutputs",
    "mris_add_template",
]
