# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA = Metadata(
    id="8a6a12eb1eae4567d49625f69155e84f68466b3c.boutiques",
    name="segmentSubjectT2_autoEstimateAlveusML",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectT2AutoEstimateAlveusMlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_t2_auto_estimate_alveus_ml(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def segment_subject_t2_auto_estimate_alveus_ml(
    runner: Runner | None = None,
) -> SegmentSubjectT2AutoEstimateAlveusMlOutputs:
    """
    A Freesurfer tool to segment T2 subjects with automatic alveus ML estimation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectT2AutoEstimateAlveusMlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA)
    cargs = []
    cargs.append("segmentSubjectT2_autoEstimateAlveusML")
    ret = SegmentSubjectT2AutoEstimateAlveusMlOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA",
    "SegmentSubjectT2AutoEstimateAlveusMlOutputs",
    "segment_subject_t2_auto_estimate_alveus_ml",
]
