# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TAL_COMPARE_METADATA = Metadata(
    id="bd1f3a28d4c8c84481961fd651bc3318b4c7368c.boutiques",
    name="tal_compare",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalCompareOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tal_compare(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    comparison_results: OutputPathType
    """Comparison results output file."""


def tal_compare(
    ref_file: InputPathType,
    moving_file: InputPathType,
    output_file: str,
    verbose: bool = False,
    runner: Runner | None = None,
) -> TalCompareOutputs:
    """
    Tool for comparing TAL databases.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        ref_file: Reference TAL database file.
        moving_file: Moving TAL database file to compare against the reference.
        output_file: Output file to store comparison results.
        verbose: Enable verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalCompareOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TAL_COMPARE_METADATA)
    cargs = []
    cargs.append("tal_compare")
    cargs.append(execution.input_file(ref_file))
    cargs.append(execution.input_file(moving_file))
    cargs.append(output_file)
    if verbose:
        cargs.append("-v")
    ret = TalCompareOutputs(
        root=execution.output_file("."),
        comparison_results=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TAL_COMPARE_METADATA",
    "TalCompareOutputs",
    "tal_compare",
]
