# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MINC2SEQINFO_METADATA = Metadata(
    id="30fbf462a54b5ca1f7c6f0f4e71bda9dbde0712d.boutiques",
    name="minc2seqinfo",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Minc2seqinfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `minc2seqinfo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_seqinfofile: OutputPathType
    """File containing the extracted sequence information."""


def minc2seqinfo(
    mincfile: InputPathType,
    seqinfofile: str,
    runner: Runner | None = None,
) -> Minc2seqinfoOutputs:
    """
    Tool for extracting sequence information from MINC files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mincfile: Input MINC file from which to extract sequence information.
        seqinfofile: Output file where the sequence information will be stored.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Minc2seqinfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MINC2SEQINFO_METADATA)
    cargs = []
    cargs.append("minc2seqinfo")
    cargs.append(execution.input_file(mincfile))
    cargs.append(seqinfofile)
    ret = Minc2seqinfoOutputs(
        root=execution.output_file("."),
        out_seqinfofile=execution.output_file(seqinfofile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MINC2SEQINFO_METADATA",
    "Minc2seqinfoOutputs",
    "minc2seqinfo",
]
