# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_CURVATURE_METADATA = Metadata(
    id="53a3b6f741f93ffb1d3ca64e3b70f76507df8aa9.boutiques",
    name="SurfaceCurvature",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class SurfaceCurvatureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_curvature(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """The processed image file."""


def surface_curvature(
    filename_in: InputPathType,
    filename_out: InputPathType,
    sigma: float,
    option: float,
    runner: Runner | None = None,
) -> SurfaceCurvatureOutputs:
    """
    The Shape Operator for Differential Analysis of Images. It can operate on binary
    or gray scale images with various modes to see different effects.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        filename_in: The input image file in .nii format.
        filename_out: The output image file in .nii format.
        sigma: The sigma value for analysis.
        option: The operation mode: 0 for mean curvature, 5 for surface\
            characterization, 6 for Gaussian curvature, and 7 for surface area.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCurvatureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CURVATURE_METADATA)
    cargs = []
    cargs.append("SurfaceCurvature" + execution.input_file(filename_in) + execution.input_file(filename_out) + str(sigma) + str(option))
    ret = SurfaceCurvatureOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(pathlib.Path(filename_out).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_CURVATURE_METADATA",
    "SurfaceCurvatureOutputs",
    "surface_curvature",
]
