# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_SPMREG_GLNXA64_METADATA = Metadata(
    id="d96fd1d83e2b7bf77ac2922d1bead84c42091878.boutiques",
    name="fs_spmreg.glnxa64",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsSpmregGlnxa64Outputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_spmreg_glnxa64(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix_file: OutputPathType
    """Output registration matrix file"""


def fs_spmreg_glnxa64(
    runner: Runner | None = None,
) -> FsSpmregGlnxa64Outputs:
    """
    fs_spmreg is a tool for registration using SPM within FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsSpmregGlnxa64Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_SPMREG_GLNXA64_METADATA)
    cargs = []
    cargs.append("fs_spmreg")
    cargs.append("[OPTIONS]")
    ret = FsSpmregGlnxa64Outputs(
        root=execution.output_file("."),
        output_matrix_file=execution.output_file("[OUTPUT_MATRIX]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_SPMREG_GLNXA64_METADATA",
    "FsSpmregGlnxa64Outputs",
    "fs_spmreg_glnxa64",
]
