# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ISANALYZE_METADATA = Metadata(
    id="3d8f8ed4f2f6a0e189b0b47b6a3b1fc896553e24.boutiques",
    name="isanalyze",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IsanalyzeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `isanalyze(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def isanalyze(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> IsanalyzeOutputs:
    """
    A tool to analyze and process IS files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file for IS analysis.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsanalyzeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ISANALYZE_METADATA)
    cargs = []
    cargs.append("isanalyze")
    cargs.append(execution.input_file(input_file))
    ret = IsanalyzeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ISANALYZE_METADATA",
    "IsanalyzeOutputs",
    "isanalyze",
]
