# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_UPDATE_METADATA = Metadata(
    id="4603b7fb31c1aa61646a36fb25725ca6a61d057f.boutiques",
    name="fs_update",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsUpdateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_update(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_update(
    update_path: str | None = None,
    help_long: bool = False,
    runner: Runner | None = None,
) -> FsUpdateOutputs:
    """
    Utility to update the FreeSurfer installation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        update_path: Path to specific files or directories to update, copied\
            recursively.
        help_long:.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsUpdateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_UPDATE_METADATA)
    cargs = []
    cargs.append("fs_update")
    if update_path is not None:
        cargs.append(update_path)
    if help_long:
        cargs.append("--help")
    ret = FsUpdateOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_UPDATE_METADATA",
    "FsUpdateOutputs",
    "fs_update",
]
