# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SURF2VTK_METADATA = Metadata(
    id="bfca7ed52c97191303bf209f7690859dfe93b483.boutiques",
    name="mris_surf2vtk",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSurf2vtkOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_surf2vtk(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    vtk_surface: OutputPathType
    """Output surface file converted to VTK format"""


def mris_surf2vtk(
    input_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisSurf2vtkOutputs:
    """
    Conversion tool to convert surface files to VTK format.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        output_surface: Output surface file in VTK format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSurf2vtkOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SURF2VTK_METADATA)
    cargs = []
    cargs.append("mris_surf2vtk")
    cargs.extend([
        "-i",
        execution.input_file(input_surface)
    ])
    cargs.extend([
        "-o",
        output_surface
    ])
    ret = MrisSurf2vtkOutputs(
        root=execution.output_file("."),
        vtk_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SURF2VTK_METADATA",
    "MrisSurf2vtkOutputs",
    "mris_surf2vtk",
]
