# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_SUBJECT_METADATA = Metadata(
    id="685f97530d830d12a67cb8468c38864b69d1e65c.boutiques",
    name="morph_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_subject(
    subjid: str,
    runner: Runner | None = None,
) -> MorphSubjectOutputs:
    """
    A morphological processing tool for Freesurfer subjects. The specific operations
    and options are not documented in the available help text.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjid: Subject ID for processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_SUBJECT_METADATA)
    cargs = []
    cargs.append("morph_subject")
    cargs.append(subjid)
    ret = MorphSubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_SUBJECT_METADATA",
    "MorphSubjectOutputs",
    "morph_subject",
]
