# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REINFLATE_SUBJECT_LH_METADATA = Metadata(
    id="3a29a9cc35621246bc04494a51e4c6898d34911c.boutiques",
    name="reinflate_subject-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ReinflateSubjectLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reinflate_subject_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inflated_surface: OutputPathType
    """Reinflated left hemisphere cortical surface"""


def reinflate_subject_lh(
    subject_id: str,
    runner: Runner | None = None,
) -> ReinflateSubjectLhOutputs:
    """
    Utility to reinflate cortical surfaces for left hemisphere in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject identifier.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReinflateSubjectLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REINFLATE_SUBJECT_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "reinflate_subject" + subject_id
    ])
    ret = ReinflateSubjectLhOutputs(
        root=execution.output_file("."),
        inflated_surface=execution.output_file(subject_id + "/surf/lh.inflated"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REINFLATE_SUBJECT_LH_METADATA",
    "ReinflateSubjectLhOutputs",
    "reinflate_subject_lh",
]
