# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_RH_METADATA = Metadata(
    id="c870a2dd4beffc1dccf8c6c63c1951a8bb440f30.boutiques",
    name="inflate_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_rh(
    arguments: str | None = None,
    runner: Runner | None = None,
) -> InflateSubjectRhOutputs:
    """
    Freesurfer command to perform an operation on the right hemisphere of a
    subject's brain image data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        arguments: Arguments for the command. Placeholder due to lack of\
            detailed help text.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_RH_METADATA)
    cargs = []
    if arguments is not None:
        cargs.extend([
            "-rh",
            "inflate_subject" + arguments
        ])
    ret = InflateSubjectRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_RH_METADATA",
    "InflateSubjectRhOutputs",
    "inflate_subject_rh",
]
