"""
dcm2niix

Chris Rorden's dcm2niiX - DICOM to NIfTI converter. Converts DICOM files to
NIfTI format with optional BIDS sidecar generation.

URL: https://github.com/rordenlab/dcm2niix
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .dcm2niix import *
