# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_HISTO_EQ_METADATA = Metadata(
    id="d08f7a1c281046fe105c26dd1e467523f2a9672c.boutiques",
    name="mri_histo_eq",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriHistoEqOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_histo_eq(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_histo_eq(
    input_volume_1: InputPathType,
    input_volume_2: InputPathType,
    runner: Runner | None = None,
) -> MriHistoEqOutputs:
    """
    MRI histogram equalization tool from Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume_1: Input volume 1.
        input_volume_2: Input volume 2.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriHistoEqOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_HISTO_EQ_METADATA)
    cargs = []
    cargs.append("mri_histo_eq")
    cargs.append(execution.input_file(input_volume_1))
    cargs.append(execution.input_file(input_volume_2))
    ret = MriHistoEqOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_HISTO_EQ_METADATA",
    "MriHistoEqOutputs",
    "mri_histo_eq",
]
