# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSREALPATH_METADATA = Metadata(
    id="ef28f86a2514a0354df33824818f45a5947ff878.boutiques",
    name="fsrealpath",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsrealpathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsrealpath(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsrealpath(
    path: str,
    help_: bool = False,
    runner: Runner | None = None,
) -> FsrealpathOutputs:
    """
    Resolve symbolic links in a path.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        path: The path to resolve.
        help_: Show this help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsrealpathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSREALPATH_METADATA)
    cargs = []
    cargs.append("fsrealpath")
    cargs.append(path)
    if help_:
        cargs.append("-h")
    ret = FsrealpathOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSREALPATH_METADATA",
    "FsrealpathOutputs",
    "fsrealpath",
]
