# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MAP_CUTS_METADATA = Metadata(
    id="779b9e3d194c64fbf7ebe1bfe928f56ccdd44441.boutiques",
    name="mris_map_cuts",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMapCutsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_map_cuts(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_map_cuts(
    input_patch: InputPathType,
    output_patch: str,
    runner: Runner | None = None,
) -> MrisMapCutsOutputs:
    """
    Tool for mapping cortical surface data onto cuts.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_patch: Input patch file.
        output_patch: Output patch file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMapCutsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MAP_CUTS_METADATA)
    cargs = []
    cargs.append("mris_map_cuts")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_patch))
    cargs.append(output_patch)
    ret = MrisMapCutsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MAP_CUTS_METADATA",
    "MrisMapCutsOutputs",
    "mris_map_cuts",
]
