# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LIST_OTL_LABELS_METADATA = Metadata(
    id="2093ee83fcca985e5be56e6cc6e4676af4aa43df.boutiques",
    name="list_otl_labels",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ListOtlLabelsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list_otl_labels(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def list_otl_labels(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> ListOtlLabelsOutputs:
    """
    Tool for listing labels in an imaging file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume filename.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ListOtlLabelsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LIST_OTL_LABELS_METADATA)
    cargs = []
    cargs.append("list_otl_labels")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    ret = ListOtlLabelsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LIST_OTL_LABELS_METADATA",
    "ListOtlLabelsOutputs",
    "list_otl_labels",
]
