# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_PRINT_HELP_METADATA = Metadata(
    id="a91a6c5c64fb27bc188a085d7211176975d7d7d4.boutiques",
    name="fsPrintHelp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsPrintHelpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_print_help(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_print_help(
    arguments: str | None = None,
    runner: Runner | None = None,
) -> FsPrintHelpOutputs:
    """
    fsPrintHelp - A tool that attempts to provide help documentation for FreeSurfer
    commands.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        arguments: Any arguments that fsPrintHelp accepts.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsPrintHelpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_PRINT_HELP_METADATA)
    cargs = []
    cargs.append("fsPrintHelp")
    if arguments is not None:
        cargs.append(arguments)
    ret = FsPrintHelpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_PRINT_HELP_METADATA",
    "FsPrintHelpOutputs",
    "fs_print_help",
]
