# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_NEW_LH_METADATA = Metadata(
    id="08307c12a50c2ff8603980e07c1bcf6e9a16f2e1.boutiques",
    name="inflate_subject_new-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectNewLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_new_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inflated_surface: OutputPathType
    """Inflated surface file for the left hemisphere"""


def inflate_subject_new_lh(
    subject_dir: str,
    runner: Runner | None = None,
) -> InflateSubjectNewLhOutputs:
    """
    Tool for inflating the left hemisphere of a subject in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Directory of the subject's data in FreeSurfer.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectNewLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_NEW_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "inflate_subject_new" + subject_dir
    ])
    cargs.append("[OPTIONS]")
    ret = InflateSubjectNewLhOutputs(
        root=execution.output_file("."),
        inflated_surface=execution.output_file(subject_dir + "/surf/lh.inflated"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_NEW_LH_METADATA",
    "InflateSubjectNewLhOutputs",
    "inflate_subject_new_lh",
]
